---
title: telegraf
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.telegraf) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.telegraf?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.telegraf) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg?label=license)](https://gitea.rknet.org/ansible/xoxys.telegraf/src/branch/master/LICENSE) 

Setup [Telegraf](https://github.com/influxdata/telegraf) metrics agent.

* [Default Variables](#default-variables)
  * [telegraf_aggregators](#telegraf_aggregators)
  * [telegraf_aggregators_extra](#telegraf_aggregators_extra)
  * [telegraf_collection_jitter](#telegraf_collection_jitter)
  * [telegraf_debug](#telegraf_debug)
  * [telegraf_docker_group_name](#telegraf_docker_group_name)
  * [telegraf_flush_interval](#telegraf_flush_interval)
  * [telegraf_flush_jitter](#telegraf_flush_jitter)
  * [telegraf_global_tags](#telegraf_global_tags)
  * [telegraf_hostname](#telegraf_hostname)
  * [telegraf_interval](#telegraf_interval)
  * [telegraf_logfile](#telegraf_logfile)
  * [telegraf_logfile_rotation_interval](#telegraf_logfile_rotation_interval)
  * [telegraf_logfile_rotation_max_archives](#telegraf_logfile_rotation_max_archives)
  * [telegraf_logfile_rotation_max_size](#telegraf_logfile_rotation_max_size)
  * [telegraf_logtarget](#telegraf_logtarget)
  * [telegraf_metric_batch_size](#telegraf_metric_batch_size)
  * [telegraf_metric_buffer_limit](#telegraf_metric_buffer_limit)
  * [telegraf_omit_hostname](#telegraf_omit_hostname)
  * [telegraf_packages_extra](#telegraf_packages_extra)
  * [telegraf_plugins](#telegraf_plugins)
  * [telegraf_plugins_extra](#telegraf_plugins_extra)
  * [telegraf_precision](#telegraf_precision)
  * [telegraf_processors](#telegraf_processors)
  * [telegraf_processors_extra](#telegraf_processors_extra)
  * [telegraf_prometheus_bind_ip](#telegraf_prometheus_bind_ip)
  * [telegraf_prometheus_bind_port](#telegraf_prometheus_bind_port)
  * [telegraf_prometheus_password](#telegraf_prometheus_password)
  * [telegraf_prometheus_tls_cert_path](#telegraf_prometheus_tls_cert_path)
  * [telegraf_prometheus_tls_cert_source](#telegraf_prometheus_tls_cert_source)
  * [telegraf_prometheus_tls_enabled](#telegraf_prometheus_tls_enabled)
  * [telegraf_prometheus_tls_key_path](#telegraf_prometheus_tls_key_path)
  * [telegraf_prometheus_tls_key_source](#telegraf_prometheus_tls_key_source)
  * [telegraf_prometheus_username](#telegraf_prometheus_username)
  * [telegraf_quiet](#telegraf_quiet)
  * [telegraf_requires_docker_group](#telegraf_requires_docker_group)
  * [telegraf_round_interval](#telegraf_round_interval)
  * [telegraf_template_files](#telegraf_template_files)
* [Dependencies](#dependencies)

---

## Default Variables

### telegraf_aggregators

List of default aggregators, combined with extra.

#### Default value

```YAML
telegraf_aggregators: []
```

#### Example usage

```YAML
telegraf_aggregators:
  - plugin: foo
    config:
      - option1 = "value1"
      - option2 = "value2"
```

### telegraf_aggregators_extra

#### Default value

```YAML
telegraf_aggregators_extra: []
```

### telegraf_collection_jitter

Collection jitter is used to jitter the collection by a random amount.

#### Default value

```YAML
telegraf_collection_jitter: 0s
```

### telegraf_debug

Log at debug level.

#### Default value

```YAML
telegraf_debug: false
```

### telegraf_docker_group_name

#### Default value

```YAML
telegraf_docker_group_name: dockerroot
```

### telegraf_flush_interval

Default flushing interval for all outputs.

#### Default value

```YAML
telegraf_flush_interval: 10s
```

### telegraf_flush_jitter

Jitter the flush interval by a random amount.

#### Default value

```YAML
telegraf_flush_jitter: 0s
```

### telegraf_global_tags

List of global tags.

#### Default value

```YAML
telegraf_global_tags: []
```

#### Example usage

```YAML
telegraf_global_tags:
  - key: rack
    value: r155
  - key: switch
    value: sw5
```

### telegraf_hostname

Override default hostname.

#### Default value

```YAML
telegraf_hostname: '{{ inventory_hostname }}'
```

### telegraf_interval

Default data collection interval for all inputs.

#### Default value

```YAML
telegraf_interval: 10s
```

### telegraf_logfile

Name of the file to be logged to when using the file logtarget.

### telegraf_logfile_rotation_interval

The logfile will be rotated after the time interval specified.

### telegraf_logfile_rotation_max_archives

Maximum number of rotated archives to keep, any older logs are deleted.

### telegraf_logfile_rotation_max_size

The logfile will be rotated when it becomes larger than the specified size.

### telegraf_logtarget

Log target controls the destination for logs.

#### Default value

```YAML
telegraf_logtarget: stderr
```

### telegraf_metric_batch_size

Telegraf will send metrics to outputs in batches of this amount.

#### Default value

```YAML
telegraf_metric_batch_size: 1000
```

### telegraf_metric_buffer_limit

Maximum number of unwritten metrics per output.

#### Default value

```YAML
telegraf_metric_buffer_limit: 10000
```

### telegraf_omit_hostname

If set to True, do no set the host tag in the telegraf agent.

#### Default value

```YAML
telegraf_omit_hostname: false
```

### telegraf_packages_extra

#### Default value

```YAML
telegraf_packages_extra: []
```

### telegraf_plugins

List of default plugins, combined with extra.

#### Default value

```YAML
telegraf_plugins:
  - plugin: net
    config:
      - ignore_protocol_stats = false
      - interfaces = ["eth*"]
  - plugin: cpu
    config:
      - percpu = true
      - totalcpu = true
      - collect_cpu_time = false
      - report_active = false
  - plugin: disk
    config:
      - ignore_fs = ["tmpfs", "devtmpfs", "devfs"]
  - plugin: filestat
    config:
      - files = ["/var/log/**.log"]
  - plugin: procstat
    config:
      - pattern = ".*"
  - plugin: netstat
  - plugin: diskio
  - plugin: kernel
  - plugin: mem
  - plugin: processes
  - plugin: swap
  - plugin: system
  - plugin: kernel_vmstat
  - plugin: linux_sysctl_fs
```

### telegraf_plugins_extra

#### Default value

```YAML
telegraf_plugins_extra: []
```

### telegraf_precision

Precision will be set to the same timestamp order as the collection interval.

### telegraf_processors

List of default processors, combined with extra.

#### Default value

```YAML
telegraf_processors: []
```

#### Example usage

```YAML
telegraf_processors:
  - plugin: foo
    config:
      - option1 = "value1"
      - option2 = "value2"
```

### telegraf_processors_extra

#### Default value

```YAML
telegraf_processors_extra: []
```

### telegraf_prometheus_bind_ip

#### Default value

```YAML
telegraf_prometheus_bind_ip: 127.0.0.1
```

### telegraf_prometheus_bind_port

#### Default value

```YAML
telegraf_prometheus_bind_port: 9273
```

### telegraf_prometheus_password

Password used by Prometheus.

#### Default value

```YAML
telegraf_prometheus_password: secure
```

### telegraf_prometheus_tls_cert_path

#### Default value

```YAML
telegraf_prometheus_tls_cert_path: /etc/pki/tls/certs/mycert.pem
```

### telegraf_prometheus_tls_cert_source

#### Default value

```YAML
telegraf_prometheus_tls_cert_source: mycert.pem
```

### telegraf_prometheus_tls_enabled

#### Default value

```YAML
telegraf_prometheus_tls_enabled: false
```

### telegraf_prometheus_tls_key_path

#### Default value

```YAML
telegraf_prometheus_tls_key_path: /etc/pki/tls/private/mykey.pem
```

### telegraf_prometheus_tls_key_source

#### Default value

```YAML
telegraf_prometheus_tls_key_source: mykey.pem
```

### telegraf_prometheus_username

Username used by Prometheus.

#### Default value

```YAML
telegraf_prometheus_username: prometheus
```

### telegraf_quiet

Log only error level messages.

#### Default value

```YAML
telegraf_quiet: true
```

### telegraf_requires_docker_group

Optionally disable docker group join.

#### Default value

```YAML
telegraf_requires_docker_group: false
```

### telegraf_round_interval

Rounds collection interval to interval.

#### Default value

```YAML
telegraf_round_interval: true
```

### telegraf_template_files

Path to templates loaded into telegraf.d directory.

#### Default value

```YAML
telegraf_template_files:
  - telegraf/templates/*.conf.j2
```

## Dependencies

None.
